/*

 log.c - A mostly working PCLink server for IDEDOS 0.9x

 Written by
  Kajtar Zsolt <soci@c64.rulez.org>

    This file is part of IDEDOS the IDE64 disk operating system
    See README for copyright notice.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#include "log.h"
#include <stdarg.h>
#include <stdio.h>
#include <stdlib.h>

typedef struct Log {
    FILE *lf;
} Log;

static Log stdoutlog;

static Log *log_stdoutopen(void) {
    stdoutlog.lf = stdout;
    return &stdoutlog;
}

Log *log_open(const char *filename) {
    Log *log;
    if (filename == NULL) {
#ifdef WIN32
        filename = "ideservd.log";
#else
        return log_stdoutopen();
#endif
    }
    if (filename[0] == '-' && filename[1] == 0) {
        return log_stdoutopen();
    }
    log = (Log *)malloc(sizeof *log);
    if (log == NULL) {
        return log_stdoutopen();
    }
    log->lf = fopen(filename, "wt");
    if (log->lf == NULL) {
        log->lf = stdout;
        fprintf(log->lf, "Cannot open logfile \"%s\"\n", filename);
    }
    return log;
}

void log_print(Log *log, const char *format, ...) {
    va_list args;
    va_start(args, format);
    vfprintf(log->lf, format, args);
    va_end(args);
}

void log_flush(Log *log) {
    fflush(log->lf);
}

void log_close(Log *log) {
    if (log != &stdoutlog) {
        if (log->lf != stdout) {
            fclose(log->lf);
        }
        free(log);
    }
}
