/*

 path.h - A mostly working PCLink server for IDEDOS 0.9x

 Written by
  Kajtar Zsolt <soci@c64.rulez.org>

    This file is part of IDEDOS the IDE64 disk operating system
    See README for copyright notice.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#ifndef _PATH_H
#define _PATH_H
#include <wchar.h>
#include <time.h>
#include "ideservd.h"
#include "nameconversion.h"

typedef struct {
    c64c_t filetype[4];
    c64c_t name[17];
    unsigned char attrib;
    unsigned int size;
    time_t time;
} directory_entry_t;

enum {
    A_CLOSED      = 0x80,
    A_DELETEABLE  = 0x40,
    A_READABLE    = 0x20,
    A_WRITEABLE   = 0x10,
    A_EXECUTEABLE = 0x08,
    A_DEL         = 0x00,
    A_NORMAL      = 0x01,
    A_REL         = 0x02,
    A_DIR         = 0x03,
    A_LNK         = 0x04,
    A_ANY         = 0x07
};

struct Log;
struct dirent;

extern int directory_open(const char *, Nameconversion, int);
extern int directory_read(directory_entry_t *);
extern int directory_cook(unsigned char *, directory_entry_t *);
extern int directory_rawread(unsigned char *);
extern const char *directory_path(void);
extern const char *directory_filename(void);
extern int directory_close(void);
extern void convertfilename(const c64c_t *, char, c64c_t *, c64c_t *, unsigned char *);
extern int matchname(c64c_t *, c64c_t *);
extern const c64c_t *resolv_path(const c64c_t *, char *, unsigned char *, struct Log *, Nameconversion);
extern size_t c64toascii(char *, c64c_t, mbstate_t *);
extern void convertc64name(char *, const c64c_t *, const c64c_t *, Nameconversion);
#endif
